##  Best Practices
  * Add translations and help texts to fields: Enhance the user experience by adding translations and help texts to every entity you create, such as sections, subsections, fields, and relation values.
  * Group related attributes: Group related attributes into new subsections to reduce noise for those who don't consume or contribute to those specific attributes. You can copy links to specific sections or subsections and share them with users who contribute information.
  * Use conditional attributes: Use conditional attributes to reduce noise and minimize the information scope when attributes are only relevant for a specific fact sheet subtype or specific sets of fact sheets. For more details, see [Conditional Attributes](https://help.sap.com/docs/leanix/ea/conditional-attributes?locale=en-US&state=PRODUCTION&version=CLOUD "Conditional attributes allow fields and relations in fact sheets to be visible based on related field values. Conditional attributes enables tailoring of attributes for subtypes, streamlining subtype management.").
